Index: src/driver/cfa.cc
===================================================================
--- src/driver/cfa.cc	(revision d0542c45889ef69129b827354fcdcf68500d21f8)
+++ src/driver/cfa.cc	(revision e297ceb4e89464ae5394d409035821fc1d22eb83)
@@ -10,6 +10,6 @@
 // Created On       : Tue Aug 20 13:44:49 2002
 // Last Modified By : Peter A. Buhr
-// Last Modified On : Tue Aug  2 12:23:11 2016
-// Update Count     : 147
+// Last Modified On : Sat Aug  6 16:14:55 2016
+// Update Count     : 148
 //
 
@@ -87,5 +87,5 @@
 	bool cpp_flag = false;								// -E or -M flag, preprocessor only
 	bool std_flag = false;								// -std= flag
-	bool noincstd_flag = false;							// -no-include-std= flag
+	bool noincstd_flag = false;							// -no-include-stdhdr= flag
 	bool debugging __attribute(( unused )) = false;		// -g flag
 
@@ -145,6 +145,6 @@
 			} else if ( arg == "-nohelp" ) {
 				help = false;							// strip the nohelp flag
-			} else if ( arg == "-no-include-std" ) {
-				noincstd_flag = true;					// strip the no-include-std flag
+			} else if ( arg == "-no-include-stdhdr" ) {
+				noincstd_flag = true;					// strip the no-include-stdhdr flag
 			} else if ( arg == "-compiler" ) {
 				// use the user specified compiler
